API Reference
=============

.. toctree::
    :maxdepth: 1

    feijoa
    feijoa.jobs
    feijoa.importance
    feijoa.models
    feijoa.search
    feijoa.search.algorithms
    feijoa.search.parameters
    feijoa.storages
    feijoa.storages.rdb
    feijoa.visualization
    feijoa.utils
